%% EDA Analysis - Trial configuration file
% This is an example trial definition file for the exported vp001_acq.mat file containing EDA data.
% The EDA data were recorded with a BIOPAC MP150 system using the GSR100C module.
% 
% You can find more information about the experiment itself and the possibilities for evaluation in 
% the detailed documentation.

% Tobias Otto
% 1.0
% 24.11.2021

%% Please never rename variables !!!

%% Enter the number of trials
numTrials = 20;

%% Trial separation
% Enter the start time of the first, second, third, ..., last trial AND
% the time when the last trial ends.
% The EDAAnalysis App uses these values to 'cut' the recorded EDA data
% into trial pieces.
%
% If your recording started with the first trial of the presentation
% program the first entry should be 0.
%
% PLEASE don't forget the last entry: the time when the last trial ends
%
% All time entries are entered in seconds
trialSep = [10 30 50 70 90 110 130 150 170 191 211 231 251 271 291 311 331 351 371 391 411];

% ====>>> OR <<<====
% Use the variables trialStart and trialStop to 'cut' a long recording into
% trials or subtrials. Sometimes only special parts of a recording are
% needed for analysis. Use this two variables otherwise leave them empty.
%
% If these variables are used the variable trialSep needs to be empty !!!
% triaSep = [] !!! Otherwise an error occurs.
trialStart  = [];
trialStop   = [];


%% Stimulus onset
% Enter the time of the stimulus when it first appeared on the screen.
% The EDAAnalysis app takes into account the data used to calculate the
% EDA from the stimulus onset to the end of the trial.
% If the complete trial from trial start to trial end is to be evaluated,
% stimOnset and trialStart must contain the same times.
%
% All time entries are entered in seconds
stimOnset = [10 30 50 70 90 110 130 150 170 191 211 231 251 271 291 311 331 351 371 391];

%% Marking positions in trials
% If you want to mark special positions in time when plotting the EDA you
% can define the time, the color of the marker and the name here.
% These entries have no influence of the EDA analysis, BUT each entry here
% will result in an extra Excel file when using exportEDA.
%
% Each marker needs three entries for each trial that what defined above:
%   * Positions in time (all entries in seconds). If a marker doesn't exist
%     in a trial it has to be marked as -1 for that trial.
%   * A name of the marker
%   * Color of the marker
%               'y' --> [1 1 0] --> yellow
%               'm' --> [1 0 1] --> magenta
%               'c' --> [0 1 1] --> cyan
%               'g' --> [0 1 0] --> green
%               'b' --> [0 0 1] --> blue
%               'w' --> [1 1 1] --> white
%               'k' --> [0 0 0] --> black

% Leave variable empty in case there are no optional markers !!!
% This variable must not be omitted, otherwise an error occurs!
% sPos = [];

% Extra marker: CS+
sPos{1}.time    = [-1 33 -1 73 93 -1 -1 153 -1 194 -1 234 254 -1 294 -1 334 -1 374 -1];
sPos{1}.color   = 'g';
sPos{1}.name    = 'CS+';

% Extra marker: CS-
sPos{2}.time    = [13 -1 53 -1 -1 113 133 -1 174 -1 214 -1 -1 274 -1 314 -1 354 -1 394];
sPos{2}.color   = 'g';
sPos{2}.name    = 'CS-';

% Extra marker: CS+S
sPos{3}.time    = [-1 -1 -1 -1 93 -1 -1 153 -1 -1 -1 234 -1 -1 294 -1 -1 -1 374 -1];
sPos{3}.color   = 'g';
sPos{3}.name    = 'CS+S';

% Extra marker: CS+W
sPos{4}.time    = [-1 33 -1 73 -1 -1 -1 -1 -1 194 -1 -1 254 -1 -1 -1 334 -1 -1 -1];
sPos{4}.color   = 'g';
sPos{4}.name    = 'CS+W';

% Extra marker: UCS
sPos{5}.time    = [-1 -1 -1 -1 99 -1 -1 159 -1 -1 -1 240 -1 -1 300 -1 -1 -1 380 -1];
sPos{5}.color   = 'g';
sPos{5}.name    = 'UCS';

% Extra marker: noUCS_CS+
sPos{6}.time    = [-1 39 -1 79 -1 -1 -1 -1 -1 200 -1 -1 260 -1 -1 -1 340 -1 -1 -1];
sPos{6}.color   = 'g';
sPos{6}.name    = 'noUCS_CS+';

% Extra marker: noUCS_CS-
sPos{7}.time    = [19 -1 59 -1 -1 119 139 -1 180 -1 220 -1 -1 280 -1 320 -1 360 -1 400];
sPos{7}.color   = 'g';
sPos{7}.name    = 'noUCS_CS-';

%% Sampling rate of your setup
% Enter sampling rate for the EDA recording in HZ
samplRate = 1000;

%% Define recording system
% This defines handling and computation of the raw data that are loaded
% into the plotEDATrial program.
%
% Use only the following entries:
% For a Biopac recording system (GSR100C)   --> 'GSR100C'
% For a BrainVision Recorder system      	--> 'VisionRecorder'
recordingSystem = 'GSR100C';
