%% EDA Analysis - Trial configuration file
% Use this script to control the analysis of the EDAAnalysis App.
% Set start points for each trial and stimulus onsets, etc.
%
% The raw data must be in a separate *.mat file that is loaded first in the
% plotEDATrial program.
%   * The variable containing the raw EDA data has to be called 'data' and
%     has to be a n x 1 double vector
%   * The variable contain the units for the x axis has to be called xUnits
%     and has to be a string as well (e.g. 'Milliseconds')
% 	* The variable containing the for the y axis has to be called yUnits
% 	  and has to be a string (e.g. 'µS')
%
% After loading the raw data the trial definition file has to be loaded.

% Tobias Otto
% 1.3
% 23.07.2021

% 07.12.2012, Tobias: first draft
% 31.01.2013, Tobias: added trialStart/Stop as optional trial separation
% 13.08.2014, Tobias: more user info; added support for other recording systems
% 23.07.2021, Tobias: updated user info for EDAAnalysis App

%% Please never rename variables !!!

%% Enter the number of trials
numTrials = 9;

%% Trial separation
% Enter the start time of the first, second, third, ..., last trial AND
% the time when the last trial ends.
% The EDAAnalysis App uses these values to 'cut' the recorded EDA data 
% into trial pieces.
%
% If your recording started with the first trial of the presentation
% program the first entry should be 0.
%
% PLEASE don't forget the last entry: the time when the last trial ends
%
% All time entries are entered in seconds
trialSep = [0 15 30 45 60 75 90 105 120 135];

% ====>>> OR <<<====
% Use the variables trialStart and trialStop to 'cut' a long recording into
% trials or subtrials. Sometimes only special parts of a recording are
% needed for analysis. Use this two variables otherwise leave them empty.
%
% If these variables are used the variable trialSep needs to be empty !!!
% triaSep = [] !!! Otherwise an error occurs.
trialStart  = [];
trialStop   = [];


%% Stimulus onset
% Enter the time of the stimulus when it first appeared on the screen.
% The EDAAnalysis app takes into account the data used to calculate the 
% EDA from the stimulus onset to the end of the trial.
% If the complete trial from trial start to trial end is to be evaluated,
% stimOnset and trialStart must contain the same times. 
%
% All time entries are entered in seconds
stimOnset = [7.4 18.3 37 49.2 61.9 77 99.9 110 128];

%% Marking positions in trials
% If you want to mark special positions in time when plotting the EDA you
% can define the time, the color of the marker and the name here.
% These entries have no influence of the EDA analysis, BUT each entry here
% will result in an extra Excel file when using exportEDA.
%
% Each marker needs at least three entries for each trial that what defined above:
%
%   * Time:
%       Positions in time (all entries in seconds). If a marker doesn't exist
%       in a trial it has to be marked as -1 for that trial.
%
%   * Name:
%       A short name of the marker that appears in the EDA-Tool.
%
%   * Color:
%       Color of the marker
%               'y' --> [1 1 0] --> yellow
%               'm' --> [1 0 1] --> magenta
%               'c' --> [0 1 1] --> cyan
%               'g' --> [0 1 0] --> green
%               'b' --> [0 0 1] --> blue
%               'w' --> [1 1 1] --> white
%               'k' --> [0 0 0] --> black
%
%   * Duration (optional and for BIDS export only):
%       This is an optional marker and is only needed if you plan to export your EDA data in BIDS
%       format! This entry describes the duration of the event in case it was a stimulus
%       presentation or something else.
%
%   * Decription (optional and for BIDS export only):
%       This is an optional marker and is only needed if you plan to export your EDA data in BIDS
%       format! This entry describes the event in more detail, e.g. stimulus/file names or 
%       conditions when a stimulus occurs or why this marker was necessary

% Leave variable empty in case there are no optional markers !!! 
% This variable must not be omitted, otherwise an error occurs!
% sPos = [];

% First marker: subject CS+ presentation and optional BIDS information
sPos{1}.time        = [-1 18.9 38.5 50.5 65 78.5 103 111.1 -1];
sPos{1}.name        = 'CS+';
sPos{1}.color       = 'g';
sPos{1}.duration    = 4;
sPos{1}.description = 'CS+ Stimulus (imageA), only presented on day 1';

% Second marker: CS- without BIDS information
% sPos{2}.time    = [13.3 -1 42.3 -1 71.9 -1 104 116.3 -1];
% sPos{2}.name    = 'CS+';
% sPos{2}.color   = 'm';

% Use sPos{3} for the next optional marker

%% Sampling rate of your setup
% Enter sampling rate for the EDA recording in HZ
samplRate = 100;

%% Define recording system
% This defines handling and computation of the raw data that are loaded
% into the plotEDATrial program.
%
% Use only the following entries:
% For a Biopac recording system (GSR100C)   --> 'GSR100C' or use 'Biopac'
% For a BrainVision Recorder system      	--> 'VisionRecorder'
recordingSystem = 'Biopac';

%% BIDS information (optional and for BIDS export only)
% If you plan to export your data in BIDS format, the following data is mandatory and cannot be 
% omitted.

% Presentation time of the stimulus in s whose onset time was specified above under stimOnset.
bids.stimDuration = 3;

% Subject name
bids.subjectName = '0815';

% Number of the recorded session. If you only recorded one data set enter 1 here
bids.session        = 1;

% If you have more than one recording in one session enter the number here. In case you have only
% one data set enter 1 here.
bids.run            = 1;

% Enter a short (!) task name here. E.g.: exp, acq, reinst, etc.
bids.task           = 'exp';

% A brief description of the task in a few sentences, containing all the essential information 
% about the task in the experiment and the procedure. 
bids.taskDescription = 'This is a place to describe the task that was used to generate the data. Use this file as an example for your trialDefinition files.';

% Enter institute information.
bids.info           = 'Ruhr University Bochum, Faculty of Psychology, Cognitive Psychology, Bochum, Germany';

% Enter contact information.
bids.contact        = 'tobias.otto@ruhr-uni-bochum.de';
